@@ -21,7 +21,7 @@ Implementation of BoundingBox class and related methods
 
 from dataclasses import dataclass
 from math import ceil, floor
-from typing import List, Optional, no_type_check
+from typing import List, Optional, Sequence, no_type_check
 
 import numpy as np
 import numpy.typing as npt
@@ -29,6 +29,7 @@ from numpy import float32
 
 from ..utils.detection_types import ImageType
 from ..utils.file_utils import cocotools_available
+from ..utils.logger import logger
 
 if cocotools_available():
     import pycocotools.mask as coco_mask
@@ -140,7 +141,7 @@ def iou(boxes1: npt.NDArray[float32], boxes2: npt.NDArray[float32]) -> npt.NDArr
 
 
 class BoundingBoxError(BaseException):
-    """Special exception only for :class:`BoundingBox`"""
+    """Special exception only for `BoundingBox`"""
 
 
 @dataclass
@@ -153,19 +154,19 @@ class BoundingBox:
     ='False'. A bounding box is a disposable object. Do not change the coordinates once the have been set but define
     a new box.
 
-    :attr:`absolute_coords` indicates, whether given coordinates are in absolute or in relative terms
+    `absolute_coords` indicates, whether given coordinates are in absolute or in relative terms
 
-    :attr:`ulx`: upper left x
+    `ulx`: upper left x
 
-    :attr:`uly`: upper left y
+    `uly`: upper left y
 
-    :attr:`lrx`: lower right x
+    `lrx`: lower right x
 
-    :attr:`lry`: lower right y
+    `lry`: lower right y
 
-    :attr:`height`: height
+    `height`: height
 
-    :attr:`width`: width
+    `width`: width
     """
 
     absolute_coords: bool
@@ -241,10 +242,11 @@ class BoundingBox:
         """
         Returns the coordinates as numpy array.
 
-        :param mode: * "xyxy" for upper left/lower right point representation,
-                     * "xywh" for upper left and width/height representation or
-                     * "poly" for full eight coordinate polygon representation. x,y coordinates will be
-                     returned in counter-clockwise order.
+        :param mode: Mode for coordinate arrangement:
+                     "xyxy" for upper left/lower right point representation,
+                     "xywh" for upper left and width/height representation or
+                     "poly" for full eight coordinate polygon representation. x,y coordinates will be
+                      returned in counter-clockwise order.
 
         :param scale_x: rescale the x coordinate. Defaults to 1
         :param scale_y: rescale the y coordinate. Defaults to 1
@@ -268,10 +270,11 @@ class BoundingBox:
         """
         Returns the coordinates as list
 
-        :param mode: * "xyxy" for upper left/lower right point representation,
-                     * "xywh" for upper left and width/height representation or
-                     * "poly" for full four-point polygon representation. Points will be returned in counter-clockwise
-                       order
+        :param mode:  Mode for coordinate arrangement:
+                     "xyxy" for upper left/lower right point representation,
+                     "xywh" for upper left and width/height representation or
+                     "poly" for full eight coordinate polygon representation. x,y coordinates will be
+                      returned in counter-clockwise order.
 
         :param scale_x: rescale the x coordinate. Defaults to 1
         :param scale_y: rescale the y coordinate. Defaults to 1
@@ -354,9 +357,9 @@ class BoundingBox:
     @no_type_check
     def from_dict(cls, **kwargs) -> "BoundingBox":
         """
-        Create :class:`BoundingBox` instance from dict
+        Create `BoundingBox` instance from dict
 
-        :param kwargs: dict with  :class:`BoundingBox` attributes
+        :param kwargs: dict with  `BoundingBox` attributes
         :return: Initialized BoundingBox
         """
         return cls(**kwargs)
@@ -368,7 +371,7 @@ def intersection_box(
     """
     Returns the intersection bounding box of two boxes. Will raise a `ValueError` if the intersection is empty.
     If coords are absolute, it will floor the lower and ceil the upper coord to ensure the resulting box has same
-    coordinates as the box induces from :func:`crop_box_from_image`
+    coordinates as the box induces from `crop_box_from_image`
 
     :param box_1: bounding box
     :param box_2: bounding box
@@ -493,7 +496,7 @@ def merge_boxes(*boxes: BoundingBox) -> BoundingBox:
     Generating the smallest box containing an arbitrary tuple/list of boxes. This function is only implemented for boxes
     with absolute coords = "True".
 
-    :param boxes: An arbitrary tuple/list of bounding boxes :class:`BoundingBox` all having absolute_coords="True".
+    :param boxes: An arbitrary tuple/list of bounding boxes `BoundingBox` all having absolute_coords="True".
     """
     absolute_coords = boxes[0].absolute_coords
     assert all(box.absolute_coords == absolute_coords for box in boxes), "all boxes must have same absolute_coords"
@@ -514,9 +517,15 @@ def rescale_coords(
     scaled_total_height: float,
 ) -> BoundingBox:
     """
-    Generating a bounding box with scaled coordinates. Will rescale x coordinate with *
-    (current_total_width/scaled_total_width), resp. y coordinate with * (current_total_height/scaled_total_height),
-    while not changing anything if absolute_coords is set to False.
+    Generating a bounding box with scaled coordinates. Will rescale x coordinate with factor
+
+    * (current_total_width/scaled_total_width),
+
+    resp. y coordinate with factor
+
+    * (current_total_height/scaled_total_height),
+
+    while not changing anything if `absolute_coords` is set to False.
 
     :param box: BoudingBox to rescale
     :param current_total_width: absolute coords of width of image
@@ -538,3 +547,55 @@ def rescale_coords(
         lrx=box.lrx * scale_width,
         lry=box.lry * scale_height,
     )
+
+
+def intersection_boxes(boxes_1: Sequence[BoundingBox], boxes_2: Sequence[BoundingBox]) -> Sequence[BoundingBox]:
+    """
+    The multiple version of 'intersection_box': Given two lists of m and n bounding boxes, it will calculate the
+    pairwise intersection of both groups. There will be at most mxn intersection boxes.
+
+    :param boxes_1: sequence of m BoundingBox
+    :param boxes_2: sequence of n BoundingBox
+    :return: list of at most mxn BoundingBox
+    """
+    if boxes_1[0].absolute_coords != boxes_1[0].absolute_coords:
+        raise ValueError("absolute_coords of boxes_1 and boxes_2 mus be equal")
+    absolute_coords = boxes_1[0].absolute_coords
+    boxes1 = np.array([box.to_list(mode="xyxy") for box in boxes_1])
+    boxes2 = np.array([box.to_list(mode="xyxy") for box in boxes_2])
+    [x_min1, y_min1, x_max1, y_max1] = np.split(boxes1, 4, axis=1)  # pylint: disable=W0632
+    [x_min2, y_min2, x_max2, y_max2] = np.split(boxes2, 4, axis=1)  # pylint: disable=W0632
+
+    ulys = np.maximum(y_min1, np.transpose(y_min2))
+    lrys = np.minimum(y_max1, np.transpose(y_max2))
+    intersect_heights = np.maximum(np.zeros(ulys.shape, dtype="f4"), lrys - ulys).flatten()
+
+    ulxs = np.maximum(x_min1, np.transpose(x_min2))
+    lrxs = np.minimum(x_max1, np.transpose(x_max2))
+    intersect_widths = np.maximum(np.zeros(ulxs.shape, dtype="f4"), lrxs - ulxs).flatten()
+    np_boxes_output = np.swapaxes(
+        [ulxs.flatten(), ulys.flatten(), intersect_widths.flatten(), intersect_heights.flatten()], 1, 0
+    )
+    boxes_output = []
+    for idx in range(np_boxes_output.shape[0]):
+        try:
+            boxes_output.append(
+                BoundingBox(
+                    ulx=np_boxes_output[idx][0],
+                    uly=np_boxes_output[idx][1],
+                    width=np_boxes_output[idx][2],
+                    height=np_boxes_output[idx][3],
+                    absolute_coords=absolute_coords,
+                )
+            )
+        except BoundingBoxError:
+            log_dict = {
+                "ulx": np_boxes_output[idx][0],
+                "uly": np_boxes_output[idx][1],
+                "width": np_boxes_output[idx][2],
+                "height": np_boxes_output[idx][3],
+            }
+
+            logger.warning("intersection_boxes error %s", "", log_dict)
+
+    return boxes_output
