@@ -18,16 +18,14 @@
 """
 Init file for instances package. Place all datasets in a directory using the structure
 
-|    Deep-Doctection
-|    ├── datasets
-|    │ ├── dataset_1
-|    │ ├── dataset_2
-|    │ ├── dataset_3
+    deepdoctection
+    ├── datasets
+    │ ├── dataset_1
+    │ ├── dataset_2
+    │ ├── dataset_3
 
 If not sure use
 
-.. code:: python
-
     print(dataset_instance.dataflow.get_workdir())
 """
 
@@ -50,7 +48,8 @@ __all__ = [
     "Xfund",
     "Funsd",
     "IIITar13K",
-    "Pubtables1M",
+    "Pubtables1MDet",
+    "Pubtables1MStruct",
     "Rvlcdip",
     "DocLayNet",
 ]
