@@ -18,12 +18,12 @@
 """
 Module for DocLayNet dataset. Place the dataset as follows
 
-|    DocLayNet_core
-|    ├── COCO
-|    │ ├── test.json
-|    │ ├── val.json
-|    ├── PNG
-|    │ ├── 0a0d43e301facee9e99cc33b9b16e732dd207135f4027e75f6aea2bf117535a2.png
+    DocLayNet_core
+    ├── COCO
+    │ ├── test.json
+    │ ├── val.json
+    ├── PNG
+    │ ├── 0a0d43e301facee9e99cc33b9b16e732dd207135f4027e75f6aea2bf117535a2.png
 """
 
 import os
@@ -123,10 +123,13 @@ class DocLayNetBuilder(DataFlowBaseBuilder):
         Returns a dataflow from which you can stream datapoints of images. The following arguments affect the returns
         of the dataflow:
 
-        :param split: Split of the dataset. Can be "train","val" or "test". Default: "val"
-        :param max_datapoints: Will stop iterating after max_datapoints. Default: None
-        :param load_image: Will load the image for each datapoint.  Default: False
-        :param fake_score: Will add a fake score so that annotations look like predictions
+        `split:` Split of the dataset. Can be `train`,`val` or `test`. Default: `val`
+
+        `max_datapoints:` Will stop iterating after max_datapoints. Default: None
+
+        `load_image:` Will load the image for each datapoint.  Default: False
+
+        `fake_score:` Will add a fake score so that annotations look like predictions
 
         :return: dataflow
         """
@@ -214,9 +217,9 @@ class DocLayNetSeqBuilder(DataFlowBaseBuilder):
         Returns a dataflow from which you can stream datapoints of images. The following arguments affect the returns
         of the dataflow:
 
-        :param split: Split of the dataset. Can be "train","val" or "test". Default: "val"
-        :param max_datapoints: Will stop iterating after max_datapoints. Default: None
-        :param load_image: Will load the image for each datapoint.  Default: False
+        `split:` Split of the dataset. Can be `train`, `val` or `test`. Default: `val`
+        `max_datapoints:` Will stop iterating after max_datapoints. Default: `None`
+        `load_image:` Will load the image for each datapoint.  Default: `False`
 
         :return: dataflow
         """
