@@ -18,15 +18,15 @@
 """
 Module for Publaynet dataset. Place the dataset as follows
 
-|    publaynet
-|    ├── test
-|    │ ├── PMC_1.png
-|    ├── train
-|    │ ├── PMC_2.png
-|    ├── val
-|    │ ├── PMC_3.png
-|    ├── train.json
-|    ├── val.json
+    publaynet
+    ├── test
+    │ ├── PMC_1.png
+    ├── train
+    │ ├── PMC_2.png
+    ├── val
+    │ ├── PMC_3.png
+    ├── train.json
+    ├── val.json
 """
 
 
@@ -98,10 +98,13 @@ class PublaynetBuilder(DataFlowBaseBuilder):
         Returns a dataflow from which you can stream datapoints of images. The following arguments affect the returns
         of the dataflow:
 
-        :param split: Split of the dataset. Can be "train","val" or "test". Default: "val"
-        :param max_datapoints: Will stop iterating after max_datapoints. Default: None
-        :param load_image: Will load the image for each datapoint.  Default: False
-        :param fake_score: Will add a fake score so that annotations look like predictions
+        `split:` Split of the dataset. Can be `train`,`val` or `test`. Default: `val`
+
+        `max_datapoints:` Will stop iterating after max_datapoints. Default: `None`
+
+        `load_image:` Will load the image for each datapoint.  Default: `False`
+
+        `fake_score:` Will add a fake score so that annotations look like predictions
 
         :return: dataflow
         """
