@@ -30,7 +30,7 @@ from termcolor import colored
 
 from ..utils.fs import download
 from ..utils.logger import log_once, logger
-from ..utils.settings import Languages, LayoutType, ObjectTypes
+from ..utils.settings import CellType, Languages, LayoutType, ObjectTypes
 from ..utils.systools import get_configs_dir_path, get_weights_dir_path
 
 __all__ = ["ModelCatalog", "ModelDownloadManager", "print_model_infos", "ModelProfile"]
@@ -48,6 +48,7 @@ class ModelProfile:
     size: List[int]
     tp_model: bool = field(default=False)
     config: Optional[str] = field(default=None)
+    preprocessor_config: Optional[str] = field(default=None)
     hf_repo_id: Optional[str] = field(default=None)
     hf_model_name: Optional[str] = field(default=None)
     hf_config_file: Optional[List[str]] = field(default=None)
@@ -68,31 +69,22 @@ class ModelCatalog:
 
     To get an overview of all registered models
 
-    .. code-block:: python
-
         print(ModelCatalog.get_model_list())
 
     To get a model card for some specific model:
 
-    .. code-block:: python
-
         profile = ModelCatalog.get_profile("layout/model-800000_inf_only.data-00000-of-00001")
         print(profile.description)
 
     Some models will have their weights and configs stored in the cache. To instantiate predictors one will sometimes
     need their path. Use
 
-    .. code-block:: python
-
         path_weights = ModelCatalog.get_full_path_configs("layout/model-800000_inf_only.data-00000-of-00001")
         path_configs = ModelCatalog.get_full_path_weights("layout/model-800000_inf_only.data-00000-of-00001")
 
     To register a new model
 
-    .. code-block:: python
-
         ModelCatalog.get_full_path_configs("my_new_model")
-
     """
 
     CATALOG: Dict[str, ModelProfile] = {
@@ -383,6 +375,44 @@ class ModelCatalog:
             hf_model_name="pytorch_model.bin",
             hf_config_file=["config.json"],
         ),
+        "microsoft/table-transformer-detection/pytorch_model.bin": ModelProfile(
+            name="microsoft/table-transformer-detection/pytorch_model.bin",
+            description="Table Transformer (DETR) model trained on PubTables1M. It was introduced in the paper "
+            "PubTables-1M: Towards Comprehensive Table Extraction From Unstructured Documents by Smock et "
+            "al. This model is devoted to table detection",
+            size=[115393245],
+            tp_model=False,
+            config="microsoft/table-transformer-detection/config.json",
+            preprocessor_config="microsoft/table-transformer-detection/preprocessor_config.json",
+            hf_repo_id="microsoft/table-transformer-detection",
+            hf_model_name="pytorch_model.bin",
+            hf_config_file=["config.json", "preprocessor_config.json"],
+            categories={"1": LayoutType.table},
+            model_wrapper="HFDetrDerivedDetector",
+        ),
+        "microsoft/table-transformer-structure-recognition/pytorch_model.bin": ModelProfile(
+            name="microsoft/table-transformer-structure-recognition/pytorch_model.bin",
+            description="Table Transformer (DETR) model trained on PubTables1M. It was introduced in the paper "
+            "PubTables-1M: Towards Comprehensive Table Extraction From Unstructured Documents by Smock et "
+            "al. This model is devoted to table structure recognition and assumes to receive a cropped"
+            "table as input. It will predict rows, column and spanning cells",
+            size=[115509981],
+            tp_model=False,
+            config="microsoft/table-transformer-structure-recognition/config.json",
+            preprocessor_config="microsoft/table-transformer-structure-recognition/preprocessor_config.json",
+            hf_repo_id="microsoft/table-transformer-structure-recognition",
+            hf_model_name="pytorch_model.bin",
+            hf_config_file=["config.json", "preprocessor_config.json"],
+            categories={
+                "1": LayoutType.table,
+                "2": LayoutType.column,
+                "3": LayoutType.row,
+                "4": CellType.column_header,
+                "5": CellType.projected_row_header,
+                "6": CellType.spanning,
+            },
+            model_wrapper="HFDetrDerivedDetector",
+        ),
         "fasttext/lid.176.bin": ModelProfile(
             name="fasttext/lid.176.bin",
             description="Fasttext language detection model",
@@ -609,6 +639,20 @@ class ModelCatalog:
             return os.path.join(get_configs_dir_path(), profile.config)
         return os.path.join(get_configs_dir_path(), name)
 
+    @staticmethod
+    def get_full_path_preprocessor_configs(name: str) -> str:
+        """
+        Return the absolute path of preprocessor configs for some given weights. Preprocessor are occasionally provided
+        by the transformer library.
+
+        :param name: model name
+        :return: absolute path to the preprocessor config
+        """
+        profile = ModelCatalog.get_profile(name)
+        if profile.preprocessor_config is not None:
+            return os.path.join(get_configs_dir_path(), profile.preprocessor_config)
+        return os.path.join(get_configs_dir_path(), name)
+
     @staticmethod
     def get_model_list() -> List[str]:
         """
@@ -622,7 +666,7 @@ class ModelCatalog:
         Checks if some weights belong to a registered model
 
         :param path_weights: relative or absolute path
-        :return: True if the weights are registered in :class:`ModelCatalog`
+        :return: True if the weights are registered in `ModelCatalog`
         """
         if (ModelCatalog.get_full_path_weights(path_weights) in ModelCatalog.get_model_list()) or (
             path_weights in ModelCatalog.get_model_list()
@@ -713,8 +757,6 @@ class ModelDownloadManager:
     Class for organizing downloads of config files and weights from various sources. Internally, it will use model
     profiles to know where things are stored.
 
-    .. code-block:: python
-
         # if you are not sure about the model name use the ModelCatalog
         ModelDownloadManager.maybe_download_weights_and_configs("layout/model-800000_inf_only.data-00000-of-00001")
     """
@@ -766,7 +808,7 @@ class ModelDownloadManager:
         Load a model from the Huggingface hub for a given profile and saves the model at the directory of the given
         path.
 
-        :param profile: Profile according to :func:`ModelCatalog.get_profile(path_weights)`
+        :param profile: Profile according to `ModelCatalog.get_profile(path_weights)`
         :param absolute_path: Absolute path (incl. file name) of target file
         :param file_names: Optionally, replace the file name of the ModelCatalog. This is necessary e.g. for Tensorpack
                            models
@@ -799,7 +841,7 @@ class ModelDownloadManager:
         Load config file(s) from the Huggingface hub for a given profile and saves the model at the directory of the
         given path.
 
-        :param profile: Profile according to :func:`ModelCatalog.get_profile(path_weights)`
+        :param profile: Profile according to `ModelCatalog.get_profile(path_weights)`
         :param absolute_path:  Absolute path (incl. file name) of target file
         """
 
