@@ -30,7 +30,7 @@ import numpy as np
 
 from ..utils.context import save_tmp_file, timeout_manager
 from ..utils.detection_types import ImageType, Requirement
-from ..utils.file_utils import TesseractNotFound, get_tesseract_requirement
+from ..utils.file_utils import _TESS_PATH, TesseractNotFound, get_tesseract_requirement
 from ..utils.metacfg import config_to_cli_str, set_config_by_yaml
 from ..utils.settings import LayoutType, ObjectTypes
 from .base import DetectionResult, ObjectDetector, PredictorBase
@@ -93,7 +93,7 @@ def _input_to_cli_str(lang: str, config: str, nice: int, input_file_name: str, o
     if not sys.platform.startswith("win32") and nice != 0:
         cmd_args += ("nice", "-n", str(nice))
 
-    cmd_args += ("tesseract", input_file_name, output_file_name_base, "-l", lang)
+    cmd_args += (_TESS_PATH, input_file_name, output_file_name_base, "-l", lang)
 
     if config:
         cmd_args += shlex.split(config)
@@ -121,7 +121,7 @@ def _run_tesseract(tesseract_args: List[str]) -> None:
 
 def image_to_dict(image: ImageType, lang: str, config: str) -> Dict[str, List[Union[str, int, float]]]:
     """
-    This is more or less :func:pytesseract.image_to_data with a dict as returned value.
+    This is more or less pytesseract.image_to_data with a dict as returned value.
     What happens under the hood is:
 
     - saving an image file
@@ -263,8 +263,6 @@ class TesseractOcrDetector(ObjectDetector):
     All configuration options that are available via pytesseract can be given via the configuration. The best overview
     can be found at https://pypi.org/project/pytesseract/.
 
-    .. code-block:: python
-
         tesseract_config_path = ModelCatalog.get_full_path_configs("dd/conf_tesseract.yaml")
         ocr_detector = TesseractOcrDetector(tesseract_config_path)
 
@@ -272,8 +270,6 @@ class TesseractOcrDetector(ObjectDetector):
 
     To use it within a pipeline
 
-    .. code-block:: python
-
         tesseract_config_path = ModelCatalog.get_full_path_configs("dd/conf_tesseract.yaml")
         ocr_detector = TesseractOcrDetector(tesseract_config_path)
 
@@ -298,7 +294,7 @@ class TesseractOcrDetector(ObjectDetector):
         :param config_overwrite: Overwrite config parameters defined by the yaml file with new values.
                                  E.g. ["oem=14"]
         """
-        self.name = "tesseract"
+        self.name = _TESS_PATH
         if config_overwrite is None:
             config_overwrite = []
 
