@@ -23,8 +23,12 @@ Module for mapping annotations into standard Detectron2 dataset dict
 import os.path
 from typing import Dict, List, Optional, Sequence, Union
 
+import numpy as np
+import torch
+from detectron2.layers import batched_nms
 from detectron2.structures import BoxMode
 
+from ..datapoint.annotation import ImageAnnotation
 from ..datapoint.image import Image
 from ..mapper.maputils import curry
 from ..utils.detection_types import JsonDict
@@ -39,7 +43,7 @@ def image_to_d2_frcnn_training(
 ) -> Optional[JsonDict]:
     """
     Maps an image to a standard dataset dict as described in
-    https://detectron2.readthedocs.io/en/latest/tutorials/datasets.html. It further checks if the image is physically
+    <https://detectron2.readthedocs.io/en/latest/tutorials/datasets.html>. It further checks if the image is physically
     available, for otherwise the annotation will be filtered.
     Note, that the returned dict will not suffice for training as gt for RPN and anchors still need to be created.
 
@@ -87,3 +91,37 @@ def image_to_d2_frcnn_training(
     output["annotations"] = annotations
 
     return output
+
+
+def pt_nms_image_annotations(
+    anns: Sequence[ImageAnnotation], threshold: float, image_id: Optional[str] = None
+) -> Sequence[str]:
+    """
+    Processing given image annotations through NMS. This is useful, if you want to supress some specific image
+    annotation, e.g. given by name or returned through different predictors. This is the pt version, for tf check
+    `mapper.tpstruct`
+
+    :param anns: A sequence of ImageAnnotations. All annotations will be treated as if they belong to one category
+    :param threshold: NMS threshold
+    :param image_id: id in order to get the embedding bounding box
+
+    :return: A list of annotation_ids that belong to the given input sequence and that survive the NMS process
+    """
+    if len(anns) == 1:
+        return [anns[0].annotation_id]
+    if not anns:
+        return []
+    ann_ids = np.array([ann.annotation_id for ann in anns], dtype="object")
+    if image_id:
+        boxes = torch.tensor(
+            [ann.image.get_embedding(image_id).to_list(mode="xyxy") for ann in anns if ann.image is not None]
+        )
+    else:
+        boxes = torch.tensor([ann.bounding_box.to_list(mode="xyxy") for ann in anns if ann.bounding_box is not None])
+    scores = torch.tensor([ann.score for ann in anns])
+    class_mask = torch.ones(len(boxes), dtype=torch.uint8)
+    keep = batched_nms(boxes, scores, class_mask, threshold)
+    ann_ids_keep = ann_ids[keep]
+    if not isinstance(ann_ids_keep, str):
+        return ann_ids_keep.tolist()
+    return []
