@@ -30,6 +30,7 @@ from ..utils.fs import load_image_from_file
 from ..utils.settings import (
     BioTag,
     LayoutType,
+    ObjectTypes,
     Relationships,
     TokenClasses,
     WordType,
@@ -44,8 +45,9 @@ def xfund_to_image(
     dp: JsonDict,
     load_image: bool,
     fake_score: bool,
-    category_names_mapping: Mapping[str, str],
-    ner_token_to_id_mapping: Mapping[str, str],
+    categories_dict_name_as_key: Mapping[str, str],
+    token_class_names_mapping: Mapping[str, str],
+    ner_token_to_id_mapping: Mapping[ObjectTypes, Mapping[ObjectTypes, Mapping[ObjectTypes, str]]],
 ) -> Optional[Image]:
     """
     Map a datapoint of annotation structure as given as from xfund or funsd dataset in to an Image structure
@@ -55,7 +57,8 @@ def xfund_to_image(
     :param load_image: If 'True' it will load image to attr:`Image.image`
     :param fake_score: If dp does not contain a score, a fake score with uniform random variables in (0,1)
                        will be added.
-    :param category_names_mapping: A dictionary, mapping original label names to normalized category names
+    :param categories_dict_name_as_key:
+    :param token_class_names_mapping: A dictionary, mapping original label names to normalized category names
     :param ner_token_to_id_mapping: A dictionary, mapping token classes with bio tags (i.e. token tags) into their
                                     category ids.
     :return: Image
@@ -72,6 +75,9 @@ def xfund_to_image(
 
     _, file_name = os.path.split(full_path)
     external_id = dp.get("uid")
+    tag_to_id_mapping = ner_token_to_id_mapping[LayoutType.word][WordType.tag]
+    token_class_to_id_mapping = ner_token_to_id_mapping[LayoutType.word][WordType.token_class]
+    token_tag_to_id_mapping = ner_token_to_id_mapping[LayoutType.word][WordType.token_tag]
 
     with MappingContextManager(file_name) as mapping_context:
 
@@ -92,6 +98,22 @@ def xfund_to_image(
             entities = dp.get("form", [])
 
         for entity in entities:
+            box = list(map(float, entity["box"]))
+            bbox = BoundingBox(absolute_coords=True, ulx=box[0], uly=box[1], lrx=box[2], lry=box[3])
+            score = maybe_get_fake_score(fake_score)
+            entity_ann = ImageAnnotation(
+                category_name=LayoutType.text,
+                bounding_box=bbox,
+                category_id=categories_dict_name_as_key[LayoutType.text],
+                score=score,
+            )
+            category_name = token_class_names_mapping[entity["label"]]
+            sub_cat_semantic = CategoryAnnotation(
+                category_name=category_name, category_id=token_class_to_id_mapping[get_type(category_name)]
+            )
+            entity_ann.dump_sub_category(WordType.token_class, sub_cat_semantic)
+            image.dump(entity_ann)
+
             words = entity.get("words")
 
             for idx, word in enumerate(words):
@@ -99,29 +121,41 @@ def xfund_to_image(
                 bbox = BoundingBox(absolute_coords=True, ulx=box[0], uly=box[1], lrx=box[2], lry=box[3])
 
                 score = maybe_get_fake_score(fake_score)
-                category_name = category_names_mapping[entity["label"]]
-                ann = ImageAnnotation(category_name=LayoutType.word, bounding_box=bbox, category_id="1", score=score)
+
+                ann = ImageAnnotation(
+                    category_name=LayoutType.word,
+                    bounding_box=bbox,
+                    category_id=categories_dict_name_as_key[LayoutType.word],
+                    score=score,
+                )
                 image.dump(ann)
-                sub_cat_semantic = CategoryAnnotation(category_name=category_name)
+                entity_ann.dump_relationship(Relationships.child, ann.annotation_id)
+                sub_cat_semantic = CategoryAnnotation(
+                    category_name=category_name, category_id=token_class_to_id_mapping[get_type(category_name)]
+                )
                 ann.dump_sub_category(WordType.token_class, sub_cat_semantic)
                 sub_cat_chars = ContainerAnnotation(category_name=WordType.characters, value=word["text"])
                 ann.dump_sub_category(WordType.characters, sub_cat_chars)
                 if sub_cat_semantic.category_name == TokenClasses.other:
-                    sub_cat_tag = CategoryAnnotation(category_name=BioTag.outside)
+                    sub_cat_tag = CategoryAnnotation(
+                        category_name=BioTag.outside, category_id=tag_to_id_mapping[BioTag.outside]
+                    )
                     ann.dump_sub_category(WordType.tag, sub_cat_tag)
                     # populating ner token to be used for training and evaluation
                     sub_cat_ner_tok = CategoryAnnotation(
-                        category_name=BioTag.outside, category_id=ner_token_to_id_mapping[BioTag.outside]
+                        category_name=BioTag.outside, category_id=token_tag_to_id_mapping[BioTag.outside]
                     )
                     ann.dump_sub_category(WordType.token_tag, sub_cat_ner_tok)
                 elif not idx:
-                    sub_cat_tag = CategoryAnnotation(category_name=BioTag.begin)
+                    sub_cat_tag = CategoryAnnotation(
+                        category_name=BioTag.begin, category_id=tag_to_id_mapping[BioTag.begin]
+                    )
                     ann.dump_sub_category(WordType.tag, sub_cat_tag)
                     sub_cat_ner_tok = CategoryAnnotation(
                         category_name=token_class_tag_to_token_class_with_tag(
                             get_type(sub_cat_semantic.category_name), BioTag.begin
                         ),
-                        category_id=ner_token_to_id_mapping[
+                        category_id=token_tag_to_id_mapping[
                             token_class_tag_to_token_class_with_tag(
                                 get_type(sub_cat_semantic.category_name), BioTag.begin
                             )
@@ -129,13 +163,15 @@ def xfund_to_image(
                     )
                     ann.dump_sub_category(WordType.token_tag, sub_cat_ner_tok)
                 else:
-                    sub_cat_tag = CategoryAnnotation(category_name=BioTag.inside)
+                    sub_cat_tag = CategoryAnnotation(
+                        category_name=BioTag.inside, category_id=tag_to_id_mapping[BioTag.inside]
+                    )
                     ann.dump_sub_category(WordType.tag, sub_cat_tag)
                     sub_cat_ner_tok = CategoryAnnotation(
                         category_name=token_class_tag_to_token_class_with_tag(
                             get_type(sub_cat_semantic.category_name), BioTag.inside
                         ),
-                        category_id=ner_token_to_id_mapping[
+                        category_id=token_tag_to_id_mapping[
                             token_class_tag_to_token_class_with_tag(
                                 get_type(sub_cat_semantic.category_name), BioTag.inside
                             )
@@ -149,7 +185,7 @@ def xfund_to_image(
             entity_id_to_entity_link_id[entity["id"]].extend(entity["linking"])
 
         # now populating semantic links
-        word_anns = image.get_annotation()
+        word_anns = image.get_annotation(category_names=LayoutType.word)
         for word in word_anns:
             entity_id = ann_id_to_entity_id[word.annotation_id]
             all_linked_entities = list(chain(*entity_id_to_entity_link_id[entity_id]))
