@@ -6,7 +6,7 @@
 
 """
 Utilities for maintaining dependencies and dealing with external library packages. Parts of this file is adapted from
-https://github.com/huggingface/transformers/blob/master/src/transformers/file_utils.py
+<https://github.com/huggingface/transformers/blob/master/src/transformers/file_utils.py>
 """
 import importlib.util
 import multiprocessing as mp
@@ -33,7 +33,7 @@ try:
 except ValueError:
     pass
 
-_TF_ERR_MSG = "Tensorflow >=2.4.1 must be installed: https://www.tensorflow.org/install/gpu"
+_TF_ERR_MSG = "Tensorflow >=2.4.1 must be installed: <https://www.tensorflow.org/install/gpu>"
 
 
 def tf_available() -> bool:
@@ -228,8 +228,7 @@ def get_transformers_requirement() -> Requirement:
 # Detectron2 related requirements
 _DETECTRON2_AVAILABLE = importlib.util.find_spec("detectron2") is not None
 _DETECTRON2_ERR_MSG = (
-    "Detectron2 must be installed: >>install-dd-pt if you installed deepdoctection from source or "
-    "follow the official installation instructions "
+    "Detectron2 must be installed: Follow the official installation instructions "
     "https://detectron2.readthedocs.io/en/latest/tutorials/install.html"
 )
 
@@ -249,11 +248,34 @@ def get_detectron2_requirement() -> Requirement:
 
 
 # Tesseract related dependencies
-
 _TESS_AVAILABLE = which("tesseract") is not None
+# Tesseract installation path
+_TESS_PATH = "tesseract"
 _TESS_ERR_MSG = "Tesseract >=4.0 must be installed: https://tesseract-ocr.github.io/tessdoc/Installation.html"
 
 
+def set_tesseract_path(tesseract_path: str) -> None:
+    """Set the Tesseract path. If you have tesseract installed in Anaconda,
+       you can use this function to set tesseract path.
+
+    :param tesseract_path: Tesseract installation path.
+    """
+    if tesseract_path is None:
+        raise ValueError("tesseract_path is empty.")
+
+    global _TESS_AVAILABLE  # pylint: disable=W0603
+    global _TESS_PATH  # pylint: disable=W0603
+
+    tesseract_flag = which(tesseract_path)
+
+    if tesseract_flag is None:
+        _TESS_AVAILABLE = False
+    else:
+        _TESS_AVAILABLE = True
+
+    _TESS_PATH = tesseract_path
+
+
 def tesseract_available() -> bool:
     """
     Returns True if Tesseract is installed
@@ -276,7 +298,7 @@ def get_tesseract_version() -> Union[int, version.Version, version.LegacyVersion
     """
     try:
         output = subprocess.check_output(
-            ["tesseract", "--version"],
+            [_TESS_PATH, "--version"],
             stderr=subprocess.STDOUT,
             env=environ,
             stdin=subprocess.DEVNULL,
