@@ -26,7 +26,7 @@ from deepdoctection.utils.detection_types import JsonDict
 
 from ..data import get_textract_response
 from ..mapper.data import DatapointXfund
-from .data import PDF_BYTES, PDF_BYTES_2
+from .data import PDF_BYTES, PDF_BYTES_2, get_detr_categories
 
 
 @fixture(name="layoutlm_input_for_predictor")
@@ -89,3 +89,11 @@ def fixture_pdf_bytes_page_2() -> bytes:
     fixture pdf bytes
     """
     return PDF_BYTES_2
+
+
+@fixture(name="detr_categories")
+def fixture_detr_categories() -> JsonDict:
+    """
+    fixture object types
+    """
+    return get_detr_categories()
